class ControlBindingsCollection(BindingsCollection,ICollection,IEnumerable):
 """
 Represents the collection of data bindings for a control.

 

 ControlBindingsCollection(control: IBindableComponent)
 """
 def Add(self,*__args):
  """
  Add(self: ControlBindingsCollection,propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool,updateMode: DataSourceUpdateMode,nullValue: object) -> Binding

  

   Creates a binding that binds the specified control property to the specified data member of the 

    specified data source,optionally enabling formatting,propagating values to the data source 

    based on the specified update setting,setting the property to the specified value when 

    System.DBNull is returned from the data source,and adding the binding to the collection.

  

  

   propertyName: The name of the control property to bind.

   dataSource: An System.Object representing the data source.

   dataMember: The property or list to bind to.

   formattingEnabled: true to format the displayed data; otherwise,false.

   updateMode: One of the System.Windows.Forms.DataSourceUpdateMode values.

   nullValue: The System.Object to be applied to the bound control property if the data source value is 

    System.DBNull.

  

   Returns: The newly created System.Windows.Forms.Binding

  Add(self: ControlBindingsCollection,propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool,updateMode: DataSourceUpdateMode,nullValue: object,formatString: str) -> Binding

  

   Creates a binding that binds the specified control property to the specified data member of the 

    specified data source,optionally enabling formatting with the specified format string,

    propagating values to the data source based on the specified update setting,setting the 

    property to the specified value when System.DBNull is returned from the data source,and adding 

    the binding to the collection.

  

  

   propertyName: The name of the control property to bind.

   dataSource: An System.Object representing the data source.

   dataMember: The property or list to bind to.

   formattingEnabled: true to format the displayed data; otherwise,false.

   updateMode: One of the System.Windows.Forms.DataSourceUpdateMode values.

   nullValue: The System.Object to be applied to the bound control property if the data source value is 

    System.DBNull.

  

   formatString: One or more format specifier characters that indicate how a value is to be displayed.

   Returns: The newly created System.Windows.Forms.Binding

  Add(self: ControlBindingsCollection,propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool,updateMode: DataSourceUpdateMode,nullValue: object,formatString: str,formatInfo: IFormatProvider) -> Binding

  

   Creates a binding that binds the specified control property to the specified data member of the 

    specified data source,optionally enabling formatting with the specified format string,

    propagating values to the data source based on the specified update setting,setting the 

    property to the specified value when System.DBNull is returned from the data source,setting the 

    specified format provider,and adding the binding to the collection.

  

  

   propertyName: The name of the control property to bind.

   dataSource: An System.Object representing the data source.

   dataMember: The property or list to bind to.

   formattingEnabled: true to format the displayed data; otherwise,false.

   updateMode: One of the System.Windows.Forms.DataSourceUpdateMode values.

   nullValue: The System.Object to be applied to the bound control property if the data source value is 

    System.DBNull.

  

   formatString: One or more format specifier characters that indicate how a value is to be displayed

   formatInfo: An implementation of System.IFormatProvider to override default formatting behavior.

   Returns: The newly created System.Windows.Forms.Binding.

  Add(self: ControlBindingsCollection,propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool,updateMode: DataSourceUpdateMode) -> Binding

  

   Creates a binding that binds the specified control property to the specified data member of the 

    specified data source,optionally enabling formatting,propagating values to the data source 

    based on the specified update setting,and adding the binding to the collection.

  

  

   propertyName: The name of the control property to bind.

   dataSource: An System.Object representing the data source.

   dataMember: The property or list to bind to.

   formattingEnabled: true to format the displayed data; otherwise,false.

   updateMode: One of the System.Windows.Forms.DataSourceUpdateMode values.

   Returns: The newly created System.Windows.Forms.Binding.

  Add(self: ControlBindingsCollection,binding: Binding)

   Adds the specified System.Windows.Forms.Binding to the collection.

  

   binding: The System.Windows.Forms.Binding to add.

  Add(self: ControlBindingsCollection,propertyName: str,dataSource: object,dataMember: str) -> Binding

  

   Creates a System.Windows.Forms.Binding using the specified control property name,data source,

    and data member,and adds it to the collection.

  

  

   propertyName: The name of the control property to bind.

   dataSource: An System.Object that represents the data source.

   dataMember: The property or list to bind to.

   Returns: The newly created System.Windows.Forms.Binding.

  Add(self: ControlBindingsCollection,propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool) -> Binding

  

   Creates a binding with the specified control property name,data source,data member,and 

    information about whether formatting is enabled,and adds the binding to the collection.

  

  

   propertyName: The name of the control property to bind.

   dataSource: An System.Object representing the data source.

   dataMember: The property or list to bind to.

   formattingEnabled: true to format the displayed data; otherwise,false

   Returns: The newly created System.Windows.Forms.Binding.
  """
  pass
 def AddCore(self,*args):
  """
  AddCore(self: ControlBindingsCollection,dataBinding: Binding)

   Adds a binding to the collection.

  

   dataBinding: The System.Windows.Forms.Binding to add.
  """
  pass
 def Clear(self):
  """
  Clear(self: ControlBindingsCollection)

   Clears the collection of any bindings.
  """
  pass
 def ClearCore(self,*args):
  """
  ClearCore(self: ControlBindingsCollection)

   Clears the bindings in the collection.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: BindingsCollection,ccevent: CollectionChangeEventArgs)

   Raises the System.Windows.Forms.BindingsCollection.CollectionChanged event.

  

   ccevent: A System.ComponentModel.CollectionChangeEventArgs that contains the event data.
  """
  pass
 def OnCollectionChanging(self,*args):
  """
  OnCollectionChanging(self: BindingsCollection,e: CollectionChangeEventArgs)

   Raises the System.Windows.Forms.BindingsCollection.CollectionChanging event.

  

   e: A System.ComponentModel.CollectionChangeEventArgs that contains event data.
  """
  pass
 def Remove(self,binding):
  """
  Remove(self: ControlBindingsCollection,binding: Binding)

   Deletes the specified System.Windows.Forms.Binding from the collection.

  

   binding: The System.Windows.Forms.Binding to remove.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: ControlBindingsCollection,index: int)

   Deletes the System.Windows.Forms.Binding at the specified index.

  

   index: The zero-based index of the item to remove.
  """
  pass
 def RemoveCore(self,*args):
  """
  RemoveCore(self: ControlBindingsCollection,dataBinding: Binding)

   Removes the specified binding from the collection.

  

   dataBinding: The System.Windows.Forms.Binding to remove from the collection.
  """
  pass
 def ShouldSerializeMyAll(self,*args):
  """
  ShouldSerializeMyAll(self: BindingsCollection) -> bool

  

   Gets a value that indicates whether the collection should be serialized.

   Returns: true if the collection count is greater than zero; otherwise,false.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+yx.__add__(y) <==> x+yx.__add__(y) <==> x+yx.__add__(y) <==> x+yx.__add__(y) <==> x+yx.__add__(y) <==> x+yx.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,control):
  """ __new__(cls: type,control: IBindableComponent) """
  pass
 BindableComponent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.IBindableComponent the binding collection belongs to.



Get: BindableComponent(self: ControlBindingsCollection) -> IBindableComponent



"""

 Control=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the control that the collection belongs to.



Get: Control(self: ControlBindingsCollection) -> Control



"""

 DefaultDataSourceUpdateMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the default System.Windows.Forms.Binding.DataSourceUpdateMode for a System.Windows.Forms.Binding in the collection.



Get: DefaultDataSourceUpdateMode(self: ControlBindingsCollection) -> DataSourceUpdateMode



Set: DefaultDataSourceUpdateMode(self: ControlBindingsCollection)=value

"""

 List=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the bindings in the collection as an object.



"""





class PerformanceCounterManager(object,ICollectData):
 """
 Prepares performance data for the performance.dll the system loads when working with performance counters.

 

 PerformanceCounterManager()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass



class IBindingList(IList,ICollection,IEnumerable):
 """ Provides the features required to support both complex and simple scenarios when binding to a data source. """
 def AddIndex(self,property):
  """
  AddIndex(self: IBindingList,property: PropertyDescriptor)

   Adds the System.ComponentModel.PropertyDescriptor to the indexes used for searching.

  

   property: The System.ComponentModel.PropertyDescriptor to add to the indexes used for searching.
  """
  pass
 def AddNew(self):
  """
  AddNew(self: IBindingList) -> object

  

   Adds a new item to the list.

   Returns: The item added to the list.
  """
  pass
 def ApplySort(self,property,direction):
  """
  ApplySort(self: IBindingList,property: PropertyDescriptor,direction: ListSortDirection)

   Sorts the list based on a System.ComponentModel.PropertyDescriptor and a 

    System.ComponentModel.ListSortDirection.

  

  

   property: The System.ComponentModel.PropertyDescriptor to sort by.

   direction: One of the System.ComponentModel.ListSortDirection values.
  """
  pass
 def Find(self,property,key):
  """
  Find(self: IBindingList,property: PropertyDescriptor,key: object) -> int

  

   Returns the index of the row that has the given System.ComponentModel.PropertyDescriptor.

  

   property: The System.ComponentModel.PropertyDescriptor to search on.

   key: The value of the property parameter to search for.

   Returns: The index of the row that has the given System.ComponentModel.PropertyDescriptor.
  """
  pass
 def RemoveIndex(self,property):
  """
  RemoveIndex(self: IBindingList,property: PropertyDescriptor)

   Removes the System.ComponentModel.PropertyDescriptor from the indexes used for searching.

  

   property: The System.ComponentModel.PropertyDescriptor to remove from the indexes used for searching.
  """
  pass
 def RemoveSort(self):
  """
  RemoveSort(self: IBindingList)

   Removes any sort applied using 

    System.ComponentModel.IBindingList.ApplySort(System.ComponentModel.PropertyDescriptor,System.Comp

    onentModel.ListSortDirection).
  """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 AllowEdit=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets whether you can update items in the list.



Get: AllowEdit(self: IBindingList) -> bool



"""

 AllowNew=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets whether you can add items to the list using System.ComponentModel.IBindingList.AddNew.



Get: AllowNew(self: IBindingList) -> bool



"""

 AllowRemove=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets whether you can remove items from the list,using System.Collections.IList.Remove(System.Object) or System.Collections.IList.RemoveAt(System.Int32).



Get: AllowRemove(self: IBindingList) -> bool



"""

 IsSorted=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets whether the items in the list are sorted.



Get: IsSorted(self: IBindingList) -> bool



"""

 SortDirection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the direction of the sort.



Get: SortDirection(self: IBindingList) -> ListSortDirection



"""

 SortProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.ComponentModel.PropertyDescriptor that is being used for sorting.



Get: SortProperty(self: IBindingList) -> PropertyDescriptor



"""

 SupportsChangeNotification=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets whether a System.ComponentModel.IBindingList.ListChanged event is raised when the list changes or an item in the list changes.



Get: SupportsChangeNotification(self: IBindingList) -> bool



"""

 SupportsSearching=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets whether the list supports searching using the System.ComponentModel.IBindingList.Find(System.ComponentModel.PropertyDescriptor,System.Object) method.



Get: SupportsSearching(self: IBindingList) -> bool



"""

 SupportsSorting=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets whether the list supports sorting.



Get: SupportsSorting(self: IBindingList) -> bool



"""


 ListChanged=None




class ListViewItemStates(Enum,IComparable,IFormattable,IConvertible):
 """
 Defines constants that represent the possible states of a System.Windows.Forms.ListViewItem.

 

 enum (flags) ListViewItemStates,values: Checked (8),Default (32),Focused (16),Grayed (2),Hot (64),Indeterminate (256),Marked (128),Selected (1),ShowKeyboardCues (512)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Checked=None
 Default=None
 Focused=None
 Grayed=None
 Hot=None
 Indeterminate=None
 Marked=None
 Selected=None
 ShowKeyboardCues=None
 value__=None




class TypeLibImporterFlags(Enum,IComparable,IFormattable,IConvertible):
 """
 Indicates how an assembly should be produced.

 

 enum (flags) TypeLibImporterFlags,values: ImportAsAgnostic (2048),ImportAsArm (16384),ImportAsItanium (1024),ImportAsX64 (512),ImportAsX86 (256),NoDefineVersionResource (8192),None (0),PreventClassMembers (16),PrimaryInteropAssembly (1),ReflectionOnlyLoading (4096),SafeArrayAsSystemArray (4),SerializableValueClasses (32),TransformDispRetVals (8),UnsafeInterfaces (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ImportAsAgnostic=None
 ImportAsArm=None
 ImportAsItanium=None
 ImportAsX64=None
 ImportAsX86=None
 NoDefineVersionResource=None
 None=None
 PreventClassMembers=None
 PrimaryInteropAssembly=None
 ReflectionOnlyLoading=None
 SafeArrayAsSystemArray=None
 SerializableValueClasses=None
 TransformDispRetVals=None
 UnsafeInterfaces=None
 value__=None




# encoding: utf-8
# module System.Net.Configuration calls itself Configuration
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class AuthenticationModuleElement(ConfigurationElement):
 """
 Represents the type information for an authentication module. This class cannot be inherited.

 

 AuthenticationModuleElement()

 AuthenticationModuleElement(typeName: str)
 """
 @staticmethod
 def __new__(self,typeName=None):
  """
  __new__(cls: type)

  __new__(cls: type,typeName: str)
  """
  pass
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Type=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the type and assembly information for the current instance.



Get: Type(self: AuthenticationModuleElement) -> str



Set: Type(self: AuthenticationModuleElement)=value

"""



class AuthenticationModuleElementCollection(ConfigurationElementCollection,ICollection,IEnumerable):
 """
 Represents a container for authentication module configuration elements. This class cannot be inherited.

 

 AuthenticationModuleElementCollection()
 """
 def Add(self,element):
  """
  Add(self: AuthenticationModuleElementCollection,element: AuthenticationModuleElement)

   Adds an element to the collection.

  

   element: The System.Net.Configuration.AuthenticationModuleElement to add to the collection.
  """
  pass
 def BaseAdd(self,*args):
  """
  BaseAdd(self: ConfigurationElementCollection,index: int,element: ConfigurationElement)

   Adds a configuration element to the configuration element collection.

  

   index: The index location at which to add the specified System.Configuration.ConfigurationElement.

   element: The System.Configuration.ConfigurationElement to add.

  BaseAdd(self: ConfigurationElementCollection,element: ConfigurationElement,throwIfExists: bool)

   Adds a configuration element to the configuration element collection.

  

   element: The System.Configuration.ConfigurationElement to add.

   throwIfExists: true to throw an exception if the System.Configuration.ConfigurationElement specified is already 

    contained in the System.Configuration.ConfigurationElementCollection; otherwise,false.

  

  BaseAdd(self: ConfigurationElementCollection,element: ConfigurationElement)

   Adds a configuration element to the System.Configuration.ConfigurationElementCollection.

  

   element: The System.Configuration.ConfigurationElement to add.
  """
  pass
 def BaseClear(self,*args):
  """
  BaseClear(self: ConfigurationElementCollection)

   Removes all configuration element objects from the collection.
  """
  pass
 def BaseGet(self,*args):
  """
  BaseGet(self: ConfigurationElementCollection,index: int) -> ConfigurationElement

  

   Gets the configuration element at the specified index location.

  

   index: The index location of the System.Configuration.ConfigurationElement to return.

   Returns: The System.Configuration.ConfigurationElement at the specified index.

  BaseGet(self: ConfigurationElementCollection,key: object) -> ConfigurationElement

  

   Returns the configuration element with the specified key.

  

   key: The key of the element to return.

   Returns: The System.Configuration.ConfigurationElement with the specified key; otherwise,null.
  """
  pass
 def BaseGetAllKeys(self,*args):
  """
  BaseGetAllKeys(self: ConfigurationElementCollection) -> Array[object]

  

   Returns an array of the keys for all of the configuration elements contained in the 

    System.Configuration.ConfigurationElementCollection.

  

   Returns: An array that contains the keys for all of the System.Configuration.ConfigurationElement objects 

    contained in the System.Configuration.ConfigurationElementCollection.
  """
  pass
 def BaseGetKey(self,*args):
  """
  BaseGetKey(self: ConfigurationElementCollection,index: int) -> object

  

   Gets the key for the System.Configuration.ConfigurationElement at the specified index location.

  

   index: The index location for the System.Configuration.ConfigurationElement.

   Returns: The key for the specified System.Configuration.ConfigurationElement.
  """
  pass
 def BaseIndexOf(self,*args):
  """
  BaseIndexOf(self: ConfigurationElementCollection,element: ConfigurationElement) -> int

  

   The index of the specified System.Configuration.ConfigurationElement.

  

   element: The System.Configuration.ConfigurationElement for the specified index location.

   Returns: The index of the specified System.Configuration.ConfigurationElement; otherwise,-1.
  """
  pass
 def BaseIsRemoved(self,*args):
  """
  BaseIsRemoved(self: ConfigurationElementCollection,key: object) -> bool

  

   Gets a value indicating whether the System.Configuration.ConfigurationElement with the specified 

    key has been removed from the System.Configuration.ConfigurationElementCollection.

  

  

   key: The key of the element to check.

   Returns: true if the System.Configuration.ConfigurationElement with the specified key has been removed; 

    otherwise,false. The default is false.
  """
  pass
 def BaseRemove(self,*args):
  """
  BaseRemove(self: ConfigurationElementCollection,key: object)

   Removes a System.Configuration.ConfigurationElement from the collection.

  

   key: The key of the System.Configuration.ConfigurationElement to remove.
  """
  pass
 def BaseRemoveAt(self,*args):
  """
  BaseRemoveAt(self: ConfigurationElementCollection,index: int)

   Removes the System.Configuration.ConfigurationElement at the specified index location.

  

   index: The index location of the System.Configuration.ConfigurationElement to remove.
  """
  pass
 def Clear(self):
  """
  Clear(self: AuthenticationModuleElementCollection)

   Removes all elements from the collection.
  """
  pass
 def CreateNewElement(self,*args):
  """
  CreateNewElement(self: AuthenticationModuleElementCollection) -> ConfigurationElement

  CreateNewElement(self: ConfigurationElementCollection,elementName: str) -> ConfigurationElement

  

   Creates a new System.Configuration.ConfigurationElement when overridden in a derived class.

  

   elementName: The name of the System.Configuration.ConfigurationElement to create.

   Returns: A new System.Configuration.ConfigurationElement.
  """
  pass
 def DeserializeElement(self,*args):
  """
  DeserializeElement(self: ConfigurationElement,reader: XmlReader,serializeCollectionKey: bool)

   Reads XML from the configuration file.

  

   reader: The System.Xml.XmlReader that reads from the configuration file.

   serializeCollectionKey: true to serialize only the collection key properties; otherwise,false.
  """
  pass
 def GetElementKey(self,*args):
  """ GetElementKey(self: AuthenticationModuleElementCollection,element: ConfigurationElement) -> object """
  pass
 def GetTransformedAssemblyString(self,*args):
  """
  GetTransformedAssemblyString(self: ConfigurationElement,assemblyName: str) -> str

  

   Returns the transformed version of the specified assembly name.

  

   assemblyName: The name of the assembly.

   Returns: The transformed version of the assembly name. If no transformer is available,the assemblyName 

    parameter value is returned unchanged. The 

    System.Configuration.Configuration.TypeStringTransformer property is null if no transformer is 

    available.
  """
  pass
 def GetTransformedTypeString(self,*args):
  """
  GetTransformedTypeString(self: ConfigurationElement,typeName: str) -> str

  

   Returns the transformed version of the specified type name.

  

   typeName: The name of the type.

   Returns: The transformed version of the specified type name. If no transformer is available,the typeName 

    parameter value is returned unchanged. The 

    System.Configuration.Configuration.TypeStringTransformer property is null if no transformer is 

    available.
  """
  pass
 def get_Item(self,*__args):
  """
  get_Item(self: ConfigurationElement,propertyName: str) -> object

  get_Item(self: ConfigurationElement,prop: ConfigurationProperty) -> object
  """
  pass
 def IndexOf(self,element):
  """
  IndexOf(self: AuthenticationModuleElementCollection,element: AuthenticationModuleElement) -> int

  

   Returns the index of the specified configuration element.

  

   element: A System.Net.Configuration.AuthenticationModuleElement.

   Returns: The zero-based index of element.
  """
  pass
 def Init(self,*args):
  """
  Init(self: ConfigurationElement)

   Sets the System.Configuration.ConfigurationElement object to its initial state.
  """
  pass
 def InitializeDefault(self,*args):
  """
  InitializeDefault(self: ConfigurationElement)

   Used to initialize a default set of values for the System.Configuration.ConfigurationElement 

    object.
  """
  pass
 def IsElementName(self,*args):
  """
  IsElementName(self: ConfigurationElementCollection,elementName: str) -> bool

  

   Indicates whether the specified System.Configuration.ConfigurationElement exists in the 

    System.Configuration.ConfigurationElementCollection.

  

  

   elementName: The name of the element to verify.

   Returns: true if the element exists in the collection; otherwise,false. The default is false.
  """
  pass
 def IsElementRemovable(self,*args):
  """
  IsElementRemovable(self: ConfigurationElementCollection,element: ConfigurationElement) -> bool

  

   Gets a value indicating whether the specified System.Configuration.ConfigurationElement can be 

    removed from the System.Configuration.ConfigurationElementCollection.

  

  

   element: The element to check.

   Returns: true if the specified System.Configuration.ConfigurationElement can be removed from this 

    System.Configuration.ConfigurationElementCollection; otherwise,false. The default is true.
  """
  pass
 def IsModified(self,*args):
  """
  IsModified(self: ConfigurationElementCollection) -> bool

  

   Indicates whether this System.Configuration.ConfigurationElementCollection has been modified 

    since it was last saved or loaded when overridden in a derived class.

  

   Returns: true if any contained element has been modified; otherwise,false
  """
  pass
 def ListErrors(self,*args):
  """
  ListErrors(self: ConfigurationElement,errorList: IList)

   Adds the invalid-property errors in this System.Configuration.ConfigurationElement object,and 

    in all subelements,to the passed list.

  

  

   errorList: An object that implements the System.Collections.IList interface.
  """
  pass
 def OnDeserializeUnrecognizedAttribute(self,*args):
  """
  OnDeserializeUnrecognizedAttribute(self: ConfigurationElement,name: str,value: str) -> bool

  

   Gets a value indicating whether an unknown attribute is encountered during deserialization.

  

   name: The name of the unrecognized attribute.

   value: The value of the unrecognized attribute.

   Returns: true when an unknown attribute is encountered while deserializing; otherwise,false.
  """
  pass
 def OnDeserializeUnrecognizedElement(self,*args):
  """
  OnDeserializeUnrecognizedElement(self: ConfigurationElementCollection,elementName: str,reader: XmlReader) -> bool

  

   Causes the configuration system to throw an exception.

  

   elementName: The name of the unrecognized element.

   reader: An input stream that reads XML from the configuration file.

   Returns: true if the unrecognized element was deserialized successfully; otherwise,false. The default is 

    false.
  """
  pass
 def OnRequiredPropertyNotFound(self,*args):
  """
  OnRequiredPropertyNotFound(self: ConfigurationElement,name: str) -> object

  

   Throws an exception when a required property is not found.

  

   name: The name of the required attribute that was not found.

   Returns: None.
  """
  pass
 def PostDeserialize(self,*args):
  """
  PostDeserialize(self: ConfigurationElement)

   Called after deserialization.
  """
  pass
 def PreSerialize(self,*args):
  """
  PreSerialize(self: ConfigurationElement,writer: XmlWriter)

   Called before serialization.

  

   writer: The System.Xml.XmlWriter that will be used to serialize the 

    System.Configuration.ConfigurationElement.
  """
  pass
 def Remove(self,*__args):
  """
  Remove(self: AuthenticationModuleElementCollection,name: str)

   Removes the element with the specified key.

  

   name: The key of the element to remove.

  Remove(self: AuthenticationModuleElementCollection,element: AuthenticationModuleElement)

   Removes the specified configuration element from the collection.

  

   element: The System.Net.Configuration.AuthenticationModuleElement to remove.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: AuthenticationModuleElementCollection,index: int)

   Removes the element at the specified index.

  

   index: The zero-based index of the element to remove.
  """
  pass
 def Reset(self,*args):
  """
  Reset(self: ConfigurationElementCollection,parentElement: ConfigurationElement)

   Resets the System.Configuration.ConfigurationElementCollection to its unmodified state when 

    overridden in a derived class.

  

  

   parentElement: The System.Configuration.ConfigurationElement representing the collection parent element,if 

    any; otherwise,null.
  """
  pass
 def ResetModified(self,*args):
  """
  ResetModified(self: ConfigurationElementCollection)

   Resets the value of the System.Configuration.ConfigurationElementCollection.IsModified property 

    to false when overridden in a derived class.
  """
  pass
 def SerializeElement(self,*args):
  """
  SerializeElement(self: ConfigurationElementCollection,writer: XmlWriter,serializeCollectionKey: bool) -> bool

  

   Writes the configuration data to an XML element in the configuration file when overridden in a 

    derived class.

  

  

   writer: Output stream that writes XML to the configuration file.

   serializeCollectionKey: true to serialize the collection key; otherwise,false.

   Returns: true if the System.Configuration.ConfigurationElementCollection was written to the configuration 

    file successfully.
  """
  pass
 def SerializeToXmlElement(self,*args):
  """
  SerializeToXmlElement(self: ConfigurationElement,writer: XmlWriter,elementName: str) -> bool

  

   Writes the outer tags of this configuration element to the configuration file when implemented 

    in a derived class.

  

  

   writer: The System.Xml.XmlWriter that writes to the configuration file.

   elementName: The name of the System.Configuration.ConfigurationElement to be written.

   Returns: true if writing was successful; otherwise,false.
  """
  pass
 def SetPropertyValue(self,*args):
  """
  SetPropertyValue(self: ConfigurationElement,prop: ConfigurationProperty,value: object,ignoreLocks: bool)

   Sets a property to the specified value.

  

   prop: The element property to set.

   value: The value to assign to the property.

   ignoreLocks: true if the locks on the property should be ignored; otherwise,false.
  """
  pass
 def SetReadOnly(self,*args):
  """
  SetReadOnly(self: ConfigurationElementCollection)

   Sets the System.Configuration.ConfigurationElementCollection.IsReadOnly property for the 

    System.Configuration.ConfigurationElementCollection object and for all sub-elements.
  """
  pass
 def set_Item(self,*__args):
  """ set_Item(self: ConfigurationElement,propertyName: str,value: object)set_Item(self: ConfigurationElement,prop: ConfigurationProperty,value: object) """
  pass
 def Unmerge(self,*args):
  """
  Unmerge(self: ConfigurationElementCollection,sourceElement: ConfigurationElement,parentElement: ConfigurationElement,saveMode: ConfigurationSaveMode)

   Reverses the effect of merging configuration information from different levels of the 

    configuration hierarchy

  

  

   sourceElement: A System.Configuration.ConfigurationElement object at the current level containing a merged view 

    of the properties.

  

   parentElement: The parent System.Configuration.ConfigurationElement object of the current element,or null if 

    this is the top level.

  

   saveMode: A System.Configuration.ConfigurationSaveMode enumerated value that determines which property 

    values to include.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]=x.__setitem__(i,y) <==> x[i]= """
  pass
 AddElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the System.Configuration.ConfigurationElement to associate with the add operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ClearElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name for the System.Configuration.ConfigurationElement to associate with the clear operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name used to identify this collection of elements in the configuration file when overridden in a derived class.



"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of properties.



"""

 RemoveElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the System.Configuration.ConfigurationElement to associate with the remove operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ThrowOnDuplicate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether an attempt to add a duplicate System.Configuration.ConfigurationElement to the System.Configuration.ConfigurationElementCollection will cause an exception to be thrown.



"""



class AuthenticationModulesSection(ConfigurationSection):
 """
 Represents the configuration section for authentication modules. This class cannot be inherited.

 

 AuthenticationModulesSection()
 """
 AuthenticationModules=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of authentication modules in the section.



Get: AuthenticationModules(self: AuthenticationModulesSection) -> AuthenticationModuleElementCollection



"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



class BypassElement(ConfigurationElement):
 """
 Represents the address information for resources that are not retrieved using a proxy server. This class cannot be inherited.

 

 BypassElement()

 BypassElement(address: str)
 """
 @staticmethod
 def __new__(self,address=None):
  """
  __new__(cls: type)

  __new__(cls: type,address: str)
  """
  pass
 Address=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the addresses of resources that bypass the proxy server.



Get: Address(self: BypassElement) -> str



Set: Address(self: BypassElement)=value

"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



class BypassElementCollection(ConfigurationElementCollection,ICollection,IEnumerable):
 """
 Represents a container for the addresses of resources that bypass the proxy server. This class cannot be inherited.

 

 BypassElementCollection()
 """
 def Add(self,element):
  """
  Add(self: BypassElementCollection,element: BypassElement)

   Adds an element to the collection.

  

   element: The System.Net.Configuration.BypassElement to add to the collection.
  """
  pass
 def BaseAdd(self,*args):
  """
  BaseAdd(self: ConfigurationElementCollection,index: int,element: ConfigurationElement)

   Adds a configuration element to the configuration element collection.

  

   index: The index location at which to add the specified System.Configuration.ConfigurationElement.

   element: The System.Configuration.ConfigurationElement to add.

  BaseAdd(self: ConfigurationElementCollection,element: ConfigurationElement,throwIfExists: bool)

   Adds a configuration element to the configuration element collection.

  

   element: The System.Configuration.ConfigurationElement to add.

   throwIfExists: true to throw an exception if the System.Configuration.ConfigurationElement specified is already 

    contained in the System.Configuration.ConfigurationElementCollection; otherwise,false.

  

  BaseAdd(self: ConfigurationElementCollection,element: ConfigurationElement)

   Adds a configuration element to the System.Configuration.ConfigurationElementCollection.

  

   element: The System.Configuration.ConfigurationElement to add.
  """
  pass
 def BaseClear(self,*args):
  """
  BaseClear(self: ConfigurationElementCollection)

   Removes all configuration element objects from the collection.
  """
  pass
 def BaseGet(self,*args):
  """
  BaseGet(self: ConfigurationElementCollection,index: int) -> ConfigurationElement

  

   Gets the configuration element at the specified index location.

  

   index: The index location of the System.Configuration.ConfigurationElement to return.

   Returns: The System.Configuration.ConfigurationElement at the specified index.

  BaseGet(self: ConfigurationElementCollection,key: object) -> ConfigurationElement

  

   Returns the configuration element with the specified key.

  

   key: The key of the element to return.

   Returns: The System.Configuration.ConfigurationElement with the specified key; otherwise,null.
  """
  pass
 def BaseGetAllKeys(self,*args):
  """
  BaseGetAllKeys(self: ConfigurationElementCollection) -> Array[object]

  

   Returns an array of the keys for all of the configuration elements contained in the 

    System.Configuration.ConfigurationElementCollection.

  

   Returns: An array that contains the keys for all of the System.Configuration.ConfigurationElement objects 

    contained in the System.Configuration.ConfigurationElementCollection.
  """
  pass
 def BaseGetKey(self,*args):
  """
  BaseGetKey(self: ConfigurationElementCollection,index: int) -> object

  

   Gets the key for the System.Configuration.ConfigurationElement at the specified index location.

  

   index: The index location for the System.Configuration.ConfigurationElement.

   Returns: The key for the specified System.Configuration.ConfigurationElement.
  """
  pass
 def BaseIndexOf(self,*args):
  """
  BaseIndexOf(self: ConfigurationElementCollection,element: ConfigurationElement) -> int

  

   The index of the specified System.Configuration.ConfigurationElement.

  

   element: The System.Configuration.ConfigurationElement for the specified index location.

   Returns: The index of the specified System.Configuration.ConfigurationElement; otherwise,-1.
  """
  pass
 def BaseIsRemoved(self,*args):
  """
  BaseIsRemoved(self: ConfigurationElementCollection,key: object) -> bool

  

   Gets a value indicating whether the System.Configuration.ConfigurationElement with the specified 

    key has been removed from the System.Configuration.ConfigurationElementCollection.

  

  

   key: The key of the element to check.

   Returns: true if the System.Configuration.ConfigurationElement with the specified key has been removed; 

    otherwise,false. The default is false.
  """
  pass
 def BaseRemove(self,*args):
  """
  BaseRemove(self: ConfigurationElementCollection,key: object)

   Removes a System.Configuration.ConfigurationElement from the collection.

  

   key: The key of the System.Configuration.ConfigurationElement to remove.
  """
  pass
 def BaseRemoveAt(self,*args):
  """
  BaseRemoveAt(self: ConfigurationElementCollection,index: int)

   Removes the System.Configuration.ConfigurationElement at the specified index location.

  

   index: The index location of the System.Configuration.ConfigurationElement to remove.
  """
  pass
 def Clear(self):
  """
  Clear(self: BypassElementCollection)

   Removes all elements from the collection.
  """
  pass
 def CreateNewElement(self,*args):
  """
  CreateNewElement(self: BypassElementCollection) -> ConfigurationElement

  CreateNewElement(self: ConfigurationElementCollection,elementName: str) -> ConfigurationElement

  

   Creates a new System.Configuration.ConfigurationElement when overridden in a derived class.

  

   elementName: The name of the System.Configuration.ConfigurationElement to create.

   Returns: A new System.Configuration.ConfigurationElement.
  """
  pass
 def DeserializeElement(self,*args):
  """
  DeserializeElement(self: ConfigurationElement,reader: XmlReader,serializeCollectionKey: bool)

   Reads XML from the configuration file.

  

   reader: The System.Xml.XmlReader that reads from the configuration file.

   serializeCollectionKey: true to serialize only the collection key properties; otherwise,false.
  """
  pass
 def GetElementKey(self,*args):
  """ GetElementKey(self: BypassElementCollection,element: ConfigurationElement) -> object """
  pass
 def GetTransformedAssemblyString(self,*args):
  """
  GetTransformedAssemblyString(self: ConfigurationElement,assemblyName: str) -> str

  

   Returns the transformed version of the specified assembly name.

  

   assemblyName: The name of the assembly.

   Returns: The transformed version of the assembly name. If no transformer is available,the assemblyName 

    parameter value is returned unchanged. The 

    System.Configuration.Configuration.TypeStringTransformer property is null if no transformer is 

    available.
  """
  pass
 def GetTransformedTypeString(self,*args):
  """
  GetTransformedTypeString(self: ConfigurationElement,typeName: str) -> str

  

   Returns the transformed version of the specified type name.

  

   typeName: The name of the type.

   Returns: The transformed version of the specified type name. If no transformer is available,the typeName 

    parameter value is returned unchanged. The 

    System.Configuration.Configuration.TypeStringTransformer property is null if no transformer is 

    available.
  """
  pass
 def get_Item(self,*__args):
  """
  get_Item(self: ConfigurationElement,propertyName: str) -> object

  get_Item(self: ConfigurationElement,prop: ConfigurationProperty) -> object
  """
  pass
 def IndexOf(self,element):
  """
  IndexOf(self: BypassElementCollection,element: BypassElement) -> int

  

   Returns the index of the specified configuration element.

  

   element: A System.Net.Configuration.BypassElement.

   Returns: The zero-based index of element.
  """
  pass
 def Init(self,*args):
  """
  Init(self: ConfigurationElement)

   Sets the System.Configuration.ConfigurationElement object to its initial state.
  """
  pass
 def InitializeDefault(self,*args):
  """
  InitializeDefault(self: ConfigurationElement)

   Used to initialize a default set of values for the System.Configuration.ConfigurationElement 

    object.
  """
  pass
 def IsElementName(self,*args):
  """
  IsElementName(self: ConfigurationElementCollection,elementName: str) -> bool

  

   Indicates whether the specified System.Configuration.ConfigurationElement exists in the 

    System.Configuration.ConfigurationElementCollection.

  

  

   elementName: The name of the element to verify.

   Returns: true if the element exists in the collection; otherwise,false. The default is false.
  """
  pass
 def IsElementRemovable(self,*args):
  """
  IsElementRemovable(self: ConfigurationElementCollection,element: ConfigurationElement) -> bool

  

   Gets a value indicating whether the specified System.Configuration.ConfigurationElement can be 

    removed from the System.Configuration.ConfigurationElementCollection.

  

  

   element: The element to check.

   Returns: true if the specified System.Configuration.ConfigurationElement can be removed from this 

    System.Configuration.ConfigurationElementCollection; otherwise,false. The default is true.
  """
  pass
 def IsModified(self,*args):
  """
  IsModified(self: ConfigurationElementCollection) -> bool

  

   Indicates whether this System.Configuration.ConfigurationElementCollection has been modified 

    since it was last saved or loaded when overridden in a derived class.

  

   Returns: true if any contained element has been modified; otherwise,false
  """
  pass
 def ListErrors(self,*args):
  """
  ListErrors(self: ConfigurationElement,errorList: IList)

   Adds the invalid-property errors in this System.Configuration.ConfigurationElement object,and 

    in all subelements,to the passed list.

  

  

   errorList: An object that implements the System.Collections.IList interface.
  """
  pass
 def OnDeserializeUnrecognizedAttribute(self,*args):
  """
  OnDeserializeUnrecognizedAttribute(self: ConfigurationElement,name: str,value: str) -> bool

  

   Gets a value indicating whether an unknown attribute is encountered during deserialization.

  

   name: The name of the unrecognized attribute.

   value: The value of the unrecognized attribute.

   Returns: true when an unknown attribute is encountered while deserializing; otherwise,false.
  """
  pass
 def OnDeserializeUnrecognizedElement(self,*args):
  """
  OnDeserializeUnrecognizedElement(self: ConfigurationElementCollection,elementName: str,reader: XmlReader) -> bool

  

   Causes the configuration system to throw an exception.

  

   elementName: The name of the unrecognized element.

   reader: An input stream that reads XML from the configuration file.

   Returns: true if the unrecognized element was deserialized successfully; otherwise,false. The default is 

    false.
  """
  pass
 def OnRequiredPropertyNotFound(self,*args):
  """
  OnRequiredPropertyNotFound(self: ConfigurationElement,name: str) -> object

  

   Throws an exception when a required property is not found.

  

   name: The name of the required attribute that was not found.

   Returns: None.
  """
  pass
 def PostDeserialize(self,*args):
  """
  PostDeserialize(self: ConfigurationElement)

   Called after deserialization.
  """
  pass
 def PreSerialize(self,*args):
  """
  PreSerialize(self: ConfigurationElement,writer: XmlWriter)

   Called before serialization.

  

   writer: The System.Xml.XmlWriter that will be used to serialize the 

    System.Configuration.ConfigurationElement.
  """
  pass
 def Remove(self,*__args):
  """
  Remove(self: BypassElementCollection,name: str)

   Removes the element with the specified key.

  

   name: The key of the element to remove.

  Remove(self: BypassElementCollection,element: BypassElement)

   Removes the specified configuration element from the collection.

  

   element: The System.Net.Configuration.BypassElement to remove.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: BypassElementCollection,index: int)

   Removes the element at the specified index.

  

   index: The zero-based index of the element to remove.
  """
  pass
 def Reset(self,*args):
  """
  Reset(self: ConfigurationElementCollection,parentElement: ConfigurationElement)

   Resets the System.Configuration.ConfigurationElementCollection to its unmodified state when 

    overridden in a derived class.

  

  

   parentElement: The System.Configuration.ConfigurationElement representing the collection parent element,if 

    any; otherwise,null.
  """
  pass
 def ResetModified(self,*args):
  """
  ResetModified(self: ConfigurationElementCollection)

   Resets the value of the System.Configuration.ConfigurationElementCollection.IsModified property 

    to false when overridden in a derived class.
  """
  pass
 def SerializeElement(self,*args):
  """
  SerializeElement(self: ConfigurationElementCollection,writer: XmlWriter,serializeCollectionKey: bool) -> bool

  

   Writes the configuration data to an XML element in the configuration file when overridden in a 

    derived class.

  

  

   writer: Output stream that writes XML to the configuration file.

   serializeCollectionKey: true to serialize the collection key; otherwise,false.

   Returns: true if the System.Configuration.ConfigurationElementCollection was written to the configuration 

    file successfully.
  """
  pass
 def SerializeToXmlElement(self,*args):
  """
  SerializeToXmlElement(self: ConfigurationElement,writer: XmlWriter,elementName: str) -> bool

  

   Writes the outer tags of this configuration element to the configuration file when implemented 

    in a derived class.

  

  

   writer: The System.Xml.XmlWriter that writes to the configuration file.

   elementName: The name of the System.Configuration.ConfigurationElement to be written.

   Returns: true if writing was successful; otherwise,false.
  """
  pass
 def SetPropertyValue(self,*args):
  """
  SetPropertyValue(self: ConfigurationElement,prop: ConfigurationProperty,value: object,ignoreLocks: bool)

   Sets a property to the specified value.

  

   prop: The element property to set.

   value: The value to assign to the property.

   ignoreLocks: true if the locks on the property should be ignored; otherwise,false.
  """
  pass
 def SetReadOnly(self,*args):
  """
  SetReadOnly(self: ConfigurationElementCollection)

   Sets the System.Configuration.ConfigurationElementCollection.IsReadOnly property for the 

    System.Configuration.ConfigurationElementCollection object and for all sub-elements.
  """
  pass
 def set_Item(self,*__args):
  """ set_Item(self: ConfigurationElement,propertyName: str,value: object)set_Item(self: ConfigurationElement,prop: ConfigurationProperty,value: object) """
  pass
 def Unmerge(self,*args):
  """
  Unmerge(self: ConfigurationElementCollection,sourceElement: ConfigurationElement,parentElement: ConfigurationElement,saveMode: ConfigurationSaveMode)

   Reverses the effect of merging configuration information from different levels of the 

    configuration hierarchy

  

  

   sourceElement: A System.Configuration.ConfigurationElement object at the current level containing a merged view 

    of the properties.

  

   parentElement: The parent System.Configuration.ConfigurationElement object of the current element,or null if 

    this is the top level.

  

   saveMode: A System.Configuration.ConfigurationSaveMode enumerated value that determines which property 

    values to include.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]=x.__setitem__(i,y) <==> x[i]= """
  pass
 AddElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the System.Configuration.ConfigurationElement to associate with the add operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ClearElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name for the System.Configuration.ConfigurationElement to associate with the clear operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name used to identify this collection of elements in the configuration file when overridden in a derived class.



"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of properties.



"""

 RemoveElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the System.Configuration.ConfigurationElement to associate with the remove operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ThrowOnDuplicate=property(lambda self: object(),lambda self,v: None,lambda self: None)



class ConnectionManagementElement(ConfigurationElement):
 """
 Represents the maximum number of connections to a remote computer. This class cannot be inherited.

 

 ConnectionManagementElement()

 ConnectionManagementElement(address: str,maxConnection: int)
 """
 @staticmethod
 def __new__(self,address=None,maxConnection=None):
  """
  __new__(cls: type)

  __new__(cls: type,address: str,maxConnection: int)
  """
  pass
 Address=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the address for remote computers.



Get: Address(self: ConnectionManagementElement) -> str



Set: Address(self: ConnectionManagementElement)=value

"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 MaxConnection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the maximum number of connections that can be made to a remote computer.



Get: MaxConnection(self: ConnectionManagementElement) -> int



Set: MaxConnection(self: ConnectionManagementElement)=value

"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



class ConnectionManagementElementCollection(ConfigurationElementCollection,ICollection,IEnumerable):
 """
 Represents a container for connection management configuration elements. This class cannot be inherited.

 

 ConnectionManagementElementCollection()
 """
 def Add(self,element):
  """
  Add(self: ConnectionManagementElementCollection,element: ConnectionManagementElement)

   Adds an element to the collection.

  

   element: The System.Net.Configuration.ConnectionManagementElement to add to the collection.
  """
  pass
 def BaseAdd(self,*args):
  """
  BaseAdd(self: ConfigurationElementCollection,index: int,element: ConfigurationElement)

   Adds a configuration element to the configuration element collection.

  

   index: The index location at which to add the specified System.Configuration.ConfigurationElement.

   element: The System.Configuration.ConfigurationElement to add.

  BaseAdd(self: ConfigurationElementCollection,element: ConfigurationElement,throwIfExists: bool)

   Adds a configuration element to the configuration element collection.

  

   element: The System.Configuration.ConfigurationElement to add.

   throwIfExists: true to throw an exception if the System.Configuration.ConfigurationElement specified is already 

    contained in the System.Configuration.ConfigurationElementCollection; otherwise,false.

  

  BaseAdd(self: ConfigurationElementCollection,element: ConfigurationElement)

   Adds a configuration element to the System.Configuration.ConfigurationElementCollection.

  

   element: The System.Configuration.ConfigurationElement to add.
  """
  pass
 def BaseClear(self,*args):
  """
  BaseClear(self: ConfigurationElementCollection)

   Removes all configuration element objects from the collection.
  """
  pass
 def BaseGet(self,*args):
  """
  BaseGet(self: ConfigurationElementCollection,index: int) -> ConfigurationElement

  

   Gets the configuration element at the specified index location.

  

   index: The index location of the System.Configuration.ConfigurationElement to return.

   Returns: The System.Configuration.ConfigurationElement at the specified index.

  BaseGet(self: ConfigurationElementCollection,key: object) -> ConfigurationElement

  

   Returns the configuration element with the specified key.

  

   key: The key of the element to return.

   Returns: The System.Configuration.ConfigurationElement with the specified key; otherwise,null.
  """
  pass
 def BaseGetAllKeys(self,*args):
  """
  BaseGetAllKeys(self: ConfigurationElementCollection) -> Array[object]

  

   Returns an array of the keys for all of the configuration elements contained in the 

    System.Configuration.ConfigurationElementCollection.

  

   Returns: An array that contains the keys for all of the System.Configuration.ConfigurationElement objects 

    contained in the System.Configuration.ConfigurationElementCollection.
  """
  pass
 def BaseGetKey(self,*args):
  """
  BaseGetKey(self: ConfigurationElementCollection,index: int) -> object

  

   Gets the key for the System.Configuration.ConfigurationElement at the specified index location.

  

   index: The index location for the System.Configuration.ConfigurationElement.

   Returns: The key for the specified System.Configuration.ConfigurationElement.
  """
  pass
 def BaseIndexOf(self,*args):
  """
  BaseIndexOf(self: ConfigurationElementCollection,element: ConfigurationElement) -> int

  

   The index of the specified System.Configuration.ConfigurationElement.

  

   element: The System.Configuration.ConfigurationElement for the specified index location.

   Returns: The index of the specified System.Configuration.ConfigurationElement; otherwise,-1.
  """
  pass
 def BaseIsRemoved(self,*args):
  """
  BaseIsRemoved(self: ConfigurationElementCollection,key: object) -> bool

  

   Gets a value indicating whether the System.Configuration.ConfigurationElement with the specified 

    key has been removed from the System.Configuration.ConfigurationElementCollection.

  

  

   key: The key of the element to check.

   Returns: true if the System.Configuration.ConfigurationElement with the specified key has been removed; 

    otherwise,false. The default is false.
  """
  pass
 def BaseRemove(self,*args):
  """
  BaseRemove(self: ConfigurationElementCollection,key: object)

   Removes a System.Configuration.ConfigurationElement from the collection.

  

   key: The key of the System.Configuration.ConfigurationElement to remove.
  """
  pass
 def BaseRemoveAt(self,*args):
  """
  BaseRemoveAt(self: ConfigurationElementCollection,index: int)

   Removes the System.Configuration.ConfigurationElement at the specified index location.

  

   index: The index location of the System.Configuration.ConfigurationElement to remove.
  """
  pass
 def Clear(self):
  """
  Clear(self: ConnectionManagementElementCollection)

   Removes all elements from the collection.
  """
  pass
 def CreateNewElement(self,*args):
  """
  CreateNewElement(self: ConnectionManagementElementCollection) -> ConfigurationElement

  CreateNewElement(self: ConfigurationElementCollection,elementName: str) -> ConfigurationElement

  

   Creates a new System.Configuration.ConfigurationElement when overridden in a derived class.

  

   elementName: The name of the System.Configuration.ConfigurationElement to create.

   Returns: A new System.Configuration.ConfigurationElement.
  """
  pass
 def DeserializeElement(self,*args):
  """
  DeserializeElement(self: ConfigurationElement,reader: XmlReader,serializeCollectionKey: bool)

   Reads XML from the configuration file.

  

   reader: The System.Xml.XmlReader that reads from the configuration file.

   serializeCollectionKey: true to serialize only the collection key properties; otherwise,false.
  """
  pass
 def GetElementKey(self,*args):
  """ GetElementKey(self: ConnectionManagementElementCollection,element: ConfigurationElement) -> object """
  pass
 def GetTransformedAssemblyString(self,*args):
  """
  GetTransformedAssemblyString(self: ConfigurationElement,assemblyName: str) -> str

  

   Returns the transformed version of the specified assembly name.

  

   assemblyName: The name of the assembly.

   Returns: The transformed version of the assembly name. If no transformer is available,the assemblyName 

    parameter value is returned unchanged. The 

    System.Configuration.Configuration.TypeStringTransformer property is null if no transformer is 

    available.
  """
  pass
 def GetTransformedTypeString(self,*args):
  """
  GetTransformedTypeString(self: ConfigurationElement,typeName: str) -> str

  

   Returns the transformed version of the specified type name.

  

   typeName: The name of the type.

   Returns: The transformed version of the specified type name. If no transformer is available,the typeName 

    parameter value is returned unchanged. The 

    System.Configuration.Configuration.TypeStringTransformer property is null if no transformer is 

    available.
  """
  pass
 def get_Item(self,*__args):
  """
  get_Item(self: ConfigurationElement,propertyName: str) -> object

  get_Item(self: ConfigurationElement,prop: ConfigurationProperty) -> object
  """
  pass
 def IndexOf(self,element):
  """
  IndexOf(self: ConnectionManagementElementCollection,element: ConnectionManagementElement) -> int

  

   Returns the index of the specified configuration element.

  

   element: A System.Net.Configuration.ConnectionManagementElement.

   Returns: The zero-based index of element.
  """
  pass
 def Init(self,*args):
  """
  Init(self: ConfigurationElement)

   Sets the System.Configuration.ConfigurationElement object to its initial state.
  """
  pass
 def InitializeDefault(self,*args):
  """
  InitializeDefault(self: ConfigurationElement)

   Used to initialize a default set of values for the System.Configuration.ConfigurationElement 

    object.
  """
  pass
 def IsElementName(self,*args):
  """
  IsElementName(self: ConfigurationElementCollection,elementName: str) -> bool

  

   Indicates whether the specified System.Configuration.ConfigurationElement exists in the 

    System.Configuration.ConfigurationElementCollection.

  

  

   elementName: The name of the element to verify.

   Returns: true if the element exists in the collection; otherwise,false. The default is false.
  """
  pass
 def IsElementRemovable(self,*args):
  """
  IsElementRemovable(self: ConfigurationElementCollection,element: ConfigurationElement) -> bool

  

   Gets a value indicating whether the specified System.Configuration.ConfigurationElement can be 

    removed from the System.Configuration.ConfigurationElementCollection.

  

  

   element: The element to check.

   Returns: true if the specified System.Configuration.ConfigurationElement can be removed from this 

    System.Configuration.ConfigurationElementCollection; otherwise,false. The default is true.
  """
  pass
 def IsModified(self,*args):
  """
  IsModified(self: ConfigurationElementCollection) -> bool

  

   Indicates whether this System.Configuration.ConfigurationElementCollection has been modified 

    since it was last saved or loaded when overridden in a derived class.

  

   Returns: true if any contained element has been modified; otherwise,false
  """
  pass
 def ListErrors(self,*args):
  """
  ListErrors(self: ConfigurationElement,errorList: IList)

   Adds the invalid-property errors in this System.Configuration.ConfigurationElement object,and 

    in all subelements,to the passed list.

  

  

   errorList: An object that implements the System.Collections.IList interface.
  """
  pass
 def OnDeserializeUnrecognizedAttribute(self,*args):
  """
  OnDeserializeUnrecognizedAttribute(self: ConfigurationElement,name: str,value: str) -> bool

  

   Gets a value indicating whether an unknown attribute is encountered during deserialization.

  

   name: The name of the unrecognized attribute.

   value: The value of the unrecognized attribute.

   Returns: true when an unknown attribute is encountered while deserializing; otherwise,false.
  """
  pass
 def OnDeserializeUnrecognizedElement(self,*args):
  """
  OnDeserializeUnrecognizedElement(self: ConfigurationElementCollection,elementName: str,reader: XmlReader) -> bool

  

   Causes the configuration system to throw an exception.

  

   elementName: The name of the unrecognized element.

   reader: An input stream that reads XML from the configuration file.

   Returns: true if the unrecognized element was deserialized successfully; otherwise,false. The default is 

    false.
  """
  pass
 def OnRequiredPropertyNotFound(self,*args):
  """
  OnRequiredPropertyNotFound(self: ConfigurationElement,name: str) -> object

  

   Throws an exception when a required property is not found.

  

   name: The name of the required attribute that was not found.

   Returns: None.
  """
  pass
 def PostDeserialize(self,*args):
  """
  PostDeserialize(self: ConfigurationElement)

   Called after deserialization.
  """
  pass
 def PreSerialize(self,*args):
  """
  PreSerialize(self: ConfigurationElement,writer: XmlWriter)

   Called before serialization.

  

   writer: The System.Xml.XmlWriter that will be used to serialize the 

    System.Configuration.ConfigurationElement.
  """
  pass
 def Remove(self,*__args):
  """
  Remove(self: ConnectionManagementElementCollection,name: str)

   Removes the element with the specified key.

  

   name: The key of the element to remove.

  Remove(self: ConnectionManagementElementCollection,element: ConnectionManagementElement)

   Removes the specified configuration element from the collection.

  

   element: The System.Net.Configuration.ConnectionManagementElement to remove.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: ConnectionManagementElementCollection,index: int)

   Removes the element at the specified index.

  

   index: The zero-based index of the element to remove.
  """
  pass
 def Reset(self,*args):
  """
  Reset(self: ConfigurationElementCollection,parentElement: ConfigurationElement)

   Resets the System.Configuration.ConfigurationElementCollection to its unmodified state when 

    overridden in a derived class.

  

  

   parentElement: The System.Configuration.ConfigurationElement representing the collection parent element,if 

    any; otherwise,null.
  """
  pass
 def ResetModified(self,*args):
  """
  ResetModified(self: ConfigurationElementCollection)

   Resets the value of the System.Configuration.ConfigurationElementCollection.IsModified property 

    to false when overridden in a derived class.
  """
  pass
 def SerializeElement(self,*args):
  """
  SerializeElement(self: ConfigurationElementCollection,writer: XmlWriter,serializeCollectionKey: bool) -> bool

  

   Writes the configuration data to an XML element in the configuration file when overridden in a 

    derived class.

  

  

   writer: Output stream that writes XML to the configuration file.

   serializeCollectionKey: true to serialize the collection key; otherwise,false.

   Returns: true if the System.Configuration.ConfigurationElementCollection was written to the configuration 

    file successfully.
  """
  pass
 def SerializeToXmlElement(self,*args):
  """
  SerializeToXmlElement(self: ConfigurationElement,writer: XmlWriter,elementName: str) -> bool

  

   Writes the outer tags of this configuration element to the configuration file when implemented 

    in a derived class.

  

  

   writer: The System.Xml.XmlWriter that writes to the configuration file.

   elementName: The name of the System.Configuration.ConfigurationElement to be written.

   Returns: true if writing was successful; otherwise,false.
  """
  pass
 def SetPropertyValue(self,*args):
  """
  SetPropertyValue(self: ConfigurationElement,prop: ConfigurationProperty,value: object,ignoreLocks: bool)

   Sets a property to the specified value.

  

   prop: The element property to set.

   value: The value to assign to the property.

   ignoreLocks: true if the locks on the property should be ignored; otherwise,false.
  """
  pass
 def SetReadOnly(self,*args):
  """
  SetReadOnly(self: ConfigurationElementCollection)

   Sets the System.Configuration.ConfigurationElementCollection.IsReadOnly property for the 

    System.Configuration.ConfigurationElementCollection object and for all sub-elements.
  """
  pass
 def set_Item(self,*__args):
  """ set_Item(self: ConfigurationElement,propertyName: str,value: object)set_Item(self: ConfigurationElement,prop: ConfigurationProperty,value: object) """
  pass
 def Unmerge(self,*args):
  """
  Unmerge(self: ConfigurationElementCollection,sourceElement: ConfigurationElement,parentElement: ConfigurationElement,saveMode: ConfigurationSaveMode)

   Reverses the effect of merging configuration information from different levels of the 

    configuration hierarchy

  

  

   sourceElement: A System.Configuration.ConfigurationElement object at the current level containing a merged view 

    of the properties.

  

   parentElement: The parent System.Configuration.ConfigurationElement object of the current element,or null if 

    this is the top level.

  

   saveMode: A System.Configuration.ConfigurationSaveMode enumerated value that determines which property 

    values to include.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]=x.__setitem__(i,y) <==> x[i]= """
  pass
 AddElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the System.Configuration.ConfigurationElement to associate with the add operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ClearElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name for the System.Configuration.ConfigurationElement to associate with the clear operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name used to identify this collection of elements in the configuration file when overridden in a derived class.



"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of properties.



"""

 RemoveElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the System.Configuration.ConfigurationElement to associate with the remove operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ThrowOnDuplicate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether an attempt to add a duplicate System.Configuration.ConfigurationElement to the System.Configuration.ConfigurationElementCollection will cause an exception to be thrown.



"""



class ConnectionManagementSection(ConfigurationSection):
 """
 Represents the configuration section for connection management. This class cannot be inherited.

 

 ConnectionManagementSection()
 """
 ConnectionManagement=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of connection management objects in the section.



Get: ConnectionManagement(self: ConnectionManagementSection) -> ConnectionManagementElementCollection



"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



class DefaultProxySection(ConfigurationSection):
 """
 Represents the configuration section for Web proxy server usage. This class cannot be inherited.

 

 DefaultProxySection()
 """
 BypassList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of resources that are not obtained using the Web proxy server.



Get: BypassList(self: DefaultProxySection) -> BypassElementCollection



"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 Enabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether a Web proxy is used.



Get: Enabled(self: DefaultProxySection) -> bool



Set: Enabled(self: DefaultProxySection)=value

"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Module=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type information for a custom Web proxy implementation.



Get: Module(self: DefaultProxySection) -> ModuleElement



"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Proxy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the URI that identifies the Web proxy server to use.



Get: Proxy(self: DefaultProxySection) -> ProxyElement



"""

 UseDefaultCredentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether default credentials are to be used to access a Web proxy server.



Get: UseDefaultCredentials(self: DefaultProxySection) -> bool



Set: UseDefaultCredentials(self: DefaultProxySection)=value

"""



class FtpCachePolicyElement(ConfigurationElement):
 """
 Represents the default FTP cache policy for network resources. This class cannot be inherited.

 

 FtpCachePolicyElement()
 """
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 PolicyLevel=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets FTP caching behavior for the local machine.



Get: PolicyLevel(self: FtpCachePolicyElement) -> RequestCacheLevel



Set: PolicyLevel(self: FtpCachePolicyElement)=value

"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



class HttpCachePolicyElement(ConfigurationElement):
 """
 Represents the default HTTP cache policy for network resources. This class cannot be inherited.

 

 HttpCachePolicyElement()
 """
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 MaximumAge=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the maximum age permitted for a resource returned from the cache.



Get: MaximumAge(self: HttpCachePolicyElement) -> TimeSpan



Set: MaximumAge(self: HttpCachePolicyElement)=value

"""

 MaximumStale=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the maximum staleness value permitted for a resource returned from the cache.



Get: MaximumStale(self: HttpCachePolicyElement) -> TimeSpan



Set: MaximumStale(self: HttpCachePolicyElement)=value

"""

 MinimumFresh=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the minimum freshness permitted for a resource returned from the cache.



Get: MinimumFresh(self: HttpCachePolicyElement) -> TimeSpan



Set: MinimumFresh(self: HttpCachePolicyElement)=value

"""

 PolicyLevel=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets HTTP caching behavior for the local machine.



Get: PolicyLevel(self: HttpCachePolicyElement) -> HttpRequestCacheLevel



Set: PolicyLevel(self: HttpCachePolicyElement)=value

"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



class HttpListenerElement(ConfigurationElement):
 """
 Represents the HttpListener element in the configuration file. This class cannot be inherited.

 

 HttpListenerElement()
 """
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Timeouts=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: Timeouts(self: HttpListenerElement) -> HttpListenerTimeoutsElement



"""

 UnescapeRequestUrl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates if System.Net.HttpListener uses the raw unescaped URI instead of the converted URI.



Get: UnescapeRequestUrl(self: HttpListenerElement) -> bool



"""



class HttpListenerTimeoutsElement(ConfigurationElement):
 """ HttpListenerTimeoutsElement() """
 DrainEntityBody=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: DrainEntityBody(self: HttpListenerTimeoutsElement) -> TimeSpan



"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EntityBody=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: EntityBody(self: HttpListenerTimeoutsElement) -> TimeSpan



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 HeaderWait=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: HeaderWait(self: HttpListenerTimeoutsElement) -> TimeSpan



"""

 IdleConnection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IdleConnection(self: HttpListenerTimeoutsElement) -> TimeSpan



"""

 MinSendBytesPerSecond=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: MinSendBytesPerSecond(self: HttpListenerTimeoutsElement) -> Int64



"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 RequestQueue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: RequestQueue(self: HttpListenerTimeoutsElement) -> TimeSpan



"""



class HttpWebRequestElement(ConfigurationElement):
 """
 Represents the maximum length for response headers. This class cannot be inherited.

 

 HttpWebRequestElement()
 """
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 MaximumErrorResponseLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the maximum allowed length of an error response.



Get: MaximumErrorResponseLength(self: HttpWebRequestElement) -> int



Set: MaximumErrorResponseLength(self: HttpWebRequestElement)=value

"""

 MaximumResponseHeadersLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the maximum allowed length of the response headers.



Get: MaximumResponseHeadersLength(self: HttpWebRequestElement) -> int



Set: MaximumResponseHeadersLength(self: HttpWebRequestElement)=value

"""

 MaximumUnauthorizedUploadLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the maximum length of an upload in response to an unauthorized error code.



Get: MaximumUnauthorizedUploadLength(self: HttpWebRequestElement) -> int



Set: MaximumUnauthorizedUploadLength(self: HttpWebRequestElement)=value

"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 UseUnsafeHeaderParsing=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Setting this property ignores validation errors that occur during HTTP parsing.



Get: UseUnsafeHeaderParsing(self: HttpWebRequestElement) -> bool



Set: UseUnsafeHeaderParsing(self: HttpWebRequestElement)=value

"""



class Ipv6Element(ConfigurationElement):
 """
 Determines whether Internet Protocol version 6 is enabled on the local computer. This class cannot be inherited.

 

 Ipv6Element()
 """
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 Enabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that indicates whether Internet Protocol version 6 is enabled on the local computer.



Get: Enabled(self: Ipv6Element) -> bool



Set: Enabled(self: Ipv6Element)=value

"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



class MailSettingsSectionGroup(ConfigurationSectionGroup):
 """
 Initializes a new instance of the System.Net.Configuration.MailSettingsSectionGroup class.

 

 MailSettingsSectionGroup()
 """
 Smtp=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the SMTP settings for the local computer.



Get: Smtp(self: MailSettingsSectionGroup) -> SmtpSection



"""



class ModuleElement(ConfigurationElement):
 """
 Represents the type information for a custom System.Net.IWebProxy module. This class cannot be inherited.

 

 ModuleElement()
 """
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Type=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the type and assembly information for the current instance.



Get: Type(self: ModuleElement) -> str



Set: Type(self: ModuleElement)=value

"""



class NetSectionGroup(ConfigurationSectionGroup):
 """
 Gets the section group information for the networking namespaces. This class cannot be inherited.

 

 NetSectionGroup()
 """
 @staticmethod
 def GetSectionGroup(config):
  """
  GetSectionGroup(config: Configuration) -> NetSectionGroup

  

   Gets the System.Net configuration section group from the specified configuration file.

  

   config: A System.Configuration.Configuration that represents a configuration file.

   Returns: A System.Net.Configuration.NetSectionGroup that represents the System.Net settings in config.
  """
  pass
 AuthenticationModules=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration section containing the authentication modules registered for the local computer.



Get: AuthenticationModules(self: NetSectionGroup) -> AuthenticationModulesSection



"""

 ConnectionManagement=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration section containing the connection management settings for the local computer.



Get: ConnectionManagement(self: NetSectionGroup) -> ConnectionManagementSection



"""

 DefaultProxy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration section containing the default Web proxy server settings for the local computer.



Get: DefaultProxy(self: NetSectionGroup) -> DefaultProxySection



"""

 MailSettings=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration section containing the SMTP client e-mail settings for the local computer.



Get: MailSettings(self: NetSectionGroup) -> MailSettingsSectionGroup



"""

 RequestCaching=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration section containing the cache configuration settings for the local computer.



Get: RequestCaching(self: NetSectionGroup) -> RequestCachingSection



"""

 Settings=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration section containing the network settings for the local computer.



Get: Settings(self: NetSectionGroup) -> SettingsSection



"""

 WebRequestModules=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration section containing the modules registered for use with the System.Net.WebRequest class.



Get: WebRequestModules(self: NetSectionGroup) -> WebRequestModulesSection



"""



class PerformanceCountersElement(ConfigurationElement):
 """
 Represents the performance counter element in the System.Net configuration file that determines whether networking performance counters are enabled. This class cannot be inherited.

 

 PerformanceCountersElement()
 """
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 Enabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether performance counters are enabled.



Get: Enabled(self: PerformanceCountersElement) -> bool



Set: Enabled(self: PerformanceCountersElement)=value

"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



class ProxyElement(ConfigurationElement):
 """
 Identifies the configuration settings for Web proxy server. This class cannot be inherited.

 

 ProxyElement()
 """
 AutoDetect=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets and sets an System.Net.Configuration.ProxyElement.AutoDetectValues value that controls whether the Web proxy is automatically detected.



Get: AutoDetect(self: ProxyElement) -> AutoDetectValues



Set: AutoDetect(self: ProxyElement)=value

"""

 BypassOnLocal=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets and sets a value that indicates whether local resources are retrieved by using a Web proxy server.



Get: BypassOnLocal(self: ProxyElement) -> BypassOnLocalValues



Set: BypassOnLocal(self: ProxyElement)=value

"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 ProxyAddress=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets and sets the URI that identifies the Web proxy server to use.



Get: ProxyAddress(self: ProxyElement) -> Uri



Set: ProxyAddress(self: ProxyElement)=value

"""

 ScriptLocation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets and sets an System.Uri value that specifies the location of the automatic proxy detection script.



Get: ScriptLocation(self: ProxyElement) -> Uri



Set: ScriptLocation(self: ProxyElement)=value

"""

 UseSystemDefault=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets and sets a System.Boolean value that controls whether the Internet Explorer Web proxy settings are used.



Get: UseSystemDefault(self: ProxyElement) -> UseSystemDefaultValues



Set: UseSystemDefault(self: ProxyElement)=value

"""


 AutoDetectValues=None
 BypassOnLocalValues=None
 UseSystemDefaultValues=None


class RequestCachingSection(ConfigurationSection):
 """
 Represents the configuration section for cache behavior. This class cannot be inherited.

 

 RequestCachingSection()
 """
 DefaultFtpCachePolicy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the default FTP caching behavior for the local computer.



Get: DefaultFtpCachePolicy(self: RequestCachingSection) -> FtpCachePolicyElement



"""

 DefaultHttpCachePolicy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the default caching behavior for the local computer.



Get: DefaultHttpCachePolicy(self: RequestCachingSection) -> HttpCachePolicyElement



"""

 DefaultPolicyLevel=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the default cache policy level.



Get: DefaultPolicyLevel(self: RequestCachingSection) -> RequestCacheLevel



Set: DefaultPolicyLevel(self: RequestCachingSection)=value

"""

 DisableAllCaching=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that enables caching on the local computer.



Get: DisableAllCaching(self: RequestCachingSection) -> bool



Set: DisableAllCaching(self: RequestCachingSection)=value

"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 IsPrivateCache=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that indicates whether the local computer cache is private.



Get: IsPrivateCache(self: RequestCachingSection) -> bool



Set: IsPrivateCache(self: RequestCachingSection)=value

"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 UnspecifiedMaximumAge=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value used as the maximum age for cached resources that do not have expiration information.



Get: UnspecifiedMaximumAge(self: RequestCachingSection) -> TimeSpan



Set: UnspecifiedMaximumAge(self: RequestCachingSection)=value

"""



class ServicePointManagerElement(ConfigurationElement):
 """
 Represents the default settings used to create connections to a remote computer. This class cannot be inherited.

 

 ServicePointManagerElement()
 """
 CheckCertificateName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that controls checking host name information in an X509 certificate.



Get: CheckCertificateName(self: ServicePointManagerElement) -> bool



Set: CheckCertificateName(self: ServicePointManagerElement)=value

"""

 CheckCertificateRevocationList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that indicates whether the certificate is checked against the certificate authority revocation list.



Get: CheckCertificateRevocationList(self: ServicePointManagerElement) -> bool



Set: CheckCertificateRevocationList(self: ServicePointManagerElement)=value

"""

 DnsRefreshTimeout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the amount of time after which address information is refreshed.



Get: DnsRefreshTimeout(self: ServicePointManagerElement) -> int



Set: DnsRefreshTimeout(self: ServicePointManagerElement)=value

"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EnableDnsRoundRobin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that controls using different IP addresses on connections to the same server.



Get: EnableDnsRoundRobin(self: ServicePointManagerElement) -> bool



Set: EnableDnsRoundRobin(self: ServicePointManagerElement)=value

"""

 EncryptionPolicy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Net.Security.EncryptionPolicy to use.



Get: EncryptionPolicy(self: ServicePointManagerElement) -> EncryptionPolicy



Set: EncryptionPolicy(self: ServicePointManagerElement)=value

"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 Expect100Continue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that determines whether 100-Continue behavior is used.



Get: Expect100Continue(self: ServicePointManagerElement) -> bool



Set: Expect100Continue(self: ServicePointManagerElement)=value

"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 UseNagleAlgorithm=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that determines whether the Nagle algorithm is used.



Get: UseNagleAlgorithm(self: ServicePointManagerElement) -> bool



Set: UseNagleAlgorithm(self: ServicePointManagerElement)=value

"""



class SettingsSection(ConfigurationSection):
 """
 Represents the configuration section for sockets,IPv6,response headers,and service points. This class cannot be inherited.

 

 SettingsSection()
 """
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 HttpListener=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration element that controls the settings used by an System.Net.HttpListener object.



Get: HttpListener(self: SettingsSection) -> HttpListenerElement



"""

 HttpWebRequest=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration element that controls the maximum response header length.



Get: HttpWebRequest(self: SettingsSection) -> HttpWebRequestElement



"""

 Ipv6=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration element that enables Internet Protocol version 6 (IPv6).



Get: Ipv6(self: SettingsSection) -> Ipv6Element



"""

 PerformanceCounters=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration element that controls whether performance counters are enabled.



Get: PerformanceCounters(self: SettingsSection) -> PerformanceCountersElement



"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 ServicePointManager=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration element that controls settings for connections to remote host computers.



Get: ServicePointManager(self: SettingsSection) -> ServicePointManagerElement



"""

 Socket=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration element that controls settings for sockets.



Get: Socket(self: SettingsSection) -> SocketElement



"""

 WebProxyScript=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the configuration element that controls the execution timeout and download timeout of Web proxy scripts.



Get: WebProxyScript(self: SettingsSection) -> WebProxyScriptElement



"""

 WebUtility=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: WebUtility(self: SettingsSection) -> WebUtilityElement



"""



class SmtpNetworkElement(ConfigurationElement):
 """
 Represents the network element in the SMTP configuration file. This class cannot be inherited.

 

 SmtpNetworkElement()
 """
 ClientDomain=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the client domain name used in the initial SMTP protocol request to connect to an SMTP mail server.



Get: ClientDomain(self: SmtpNetworkElement) -> str



Set: ClientDomain(self: SmtpNetworkElement)=value

"""

 DefaultCredentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Determines whether or not default user credentials are used to access an SMTP server. The default value is false.



Get: DefaultCredentials(self: SmtpNetworkElement) -> bool



Set: DefaultCredentials(self: SmtpNetworkElement)=value

"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EnableSsl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether SSL is used to access an SMTP mail server. The default value is false.



Get: EnableSsl(self: SmtpNetworkElement) -> bool



Set: EnableSsl(self: SmtpNetworkElement)=value

"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Host=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the SMTP server.



Get: Host(self: SmtpNetworkElement) -> str



Set: Host(self: SmtpNetworkElement)=value

"""

 Password=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the user password to use to connect to an SMTP mail server.



Get: Password(self: SmtpNetworkElement) -> str



Set: Password(self: SmtpNetworkElement)=value

"""

 Port=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the port that SMTP clients use to connect to an SMTP mail server. The default value is 25.



Get: Port(self: SmtpNetworkElement) -> int



Set: Port(self: SmtpNetworkElement)=value

"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 TargetName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the Service Provider Name (SPN) to use for authentication when using extended protection to connect to an SMTP mail server.



Get: TargetName(self: SmtpNetworkElement) -> str



Set: TargetName(self: SmtpNetworkElement)=value

"""

 UserName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the user name to connect to an SMTP mail server.



Get: UserName(self: SmtpNetworkElement) -> str



Set: UserName(self: SmtpNetworkElement)=value

"""



class SmtpSection(ConfigurationSection):
 """
 Represents the SMTP section in the System.Net configuration file.

 

 SmtpSection()
 """
 DeliveryFormat=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: DeliveryFormat(self: SmtpSection) -> SmtpDeliveryFormat



Set: DeliveryFormat(self: SmtpSection)=value

"""

 DeliveryMethod=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the SMTP delivery method. The default delivery method is System.Net.Mail.SmtpDeliveryMethod.Network.



Get: DeliveryMethod(self: SmtpSection) -> SmtpDeliveryMethod



Set: DeliveryMethod(self: SmtpSection)=value

"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 From=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the default value that indicates who the email message is from.



Get: From(self: SmtpSection) -> str



Set: From(self: SmtpSection)=value

"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Network=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Net.Configuration.SmtpNetworkElement.



Get: Network(self: SmtpSection) -> SmtpNetworkElement



"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 SpecifiedPickupDirectory=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the pickup directory that will be used by the SMPT client.



Get: SpecifiedPickupDirectory(self: SmtpSection) -> SmtpSpecifiedPickupDirectoryElement



"""



class SmtpSpecifiedPickupDirectoryElement(ConfigurationElement):
 """
 Represents an SMTP pickup directory configuration element.

 

 SmtpSpecifiedPickupDirectoryElement()
 """
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 PickupDirectoryLocation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the folder where applications save mail messages to be processed by the SMTP server.



Get: PickupDirectoryLocation(self: SmtpSpecifiedPickupDirectoryElement) -> str



Set: PickupDirectoryLocation(self: SmtpSpecifiedPickupDirectoryElement)=value

"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



class SocketElement(ConfigurationElement):
 """
 Represents information used to configure System.Net.Sockets.Socket objects. This class cannot be inherited.

 

 SocketElement()
 """
 AlwaysUseCompletionPortsForAccept=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that specifies whether completion ports are used when accepting connections.



Get: AlwaysUseCompletionPortsForAccept(self: SocketElement) -> bool



Set: AlwaysUseCompletionPortsForAccept(self: SocketElement)=value

"""

 AlwaysUseCompletionPortsForConnect=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a Boolean value that specifies whether completion ports are used when making connections.



Get: AlwaysUseCompletionPortsForConnect(self: SocketElement) -> bool



Set: AlwaysUseCompletionPortsForConnect(self: SocketElement)=value

"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 IPProtectionLevel=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that specifies the default System.Net.Sockets.IPProtectionLevel to use for a socket.



Get: IPProtectionLevel(self: SocketElement) -> IPProtectionLevel



Set: IPProtectionLevel(self: SocketElement)=value

"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



class UnicodeDecodingConformance(Enum,IComparable,IFormattable,IConvertible):
 """ enum UnicodeDecodingConformance,values: Auto (0),Compat (2),Loose (3),Strict (1) """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Auto=None
 Compat=None
 Loose=None
 Strict=None
 value__=None


class UnicodeEncodingConformance(Enum,IComparable,IFormattable,IConvertible):
 """ enum UnicodeEncodingConformance,values: Auto (0),Compat (2),Strict (1) """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Auto=None
 Compat=None
 Strict=None
 value__=None


class WebProxyScriptElement(ConfigurationElement):
 """
 Represents information used to configure Web proxy scripts. This class cannot be inherited.

 

 WebProxyScriptElement()
 """
 DownloadTimeout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the Web proxy script download timeout using the format hours:minutes:seconds.



Get: DownloadTimeout(self: WebProxyScriptElement) -> TimeSpan



Set: DownloadTimeout(self: WebProxyScriptElement)=value

"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)



class WebRequestModuleElement(ConfigurationElement):
 """
 Represents a URI prefix and the associated class that handles creating Web requests for the prefix. This class cannot be inherited.

 

 WebRequestModuleElement()

 WebRequestModuleElement(prefix: str,type: str)

 WebRequestModuleElement(prefix: str,type: Type)
 """
 @staticmethod
 def __new__(self,prefix=None,type=None):
  """
  __new__(cls: type)

  __new__(cls: type,prefix: str,type: str)

  __new__(cls: type,prefix: str,type: Type)
  """
  pass
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Prefix=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the URI prefix for the current Web request module.



Get: Prefix(self: WebRequestModuleElement) -> str



Set: Prefix(self: WebRequestModuleElement)=value

"""

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Type=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a class that creates Web requests.



Get: Type(self: WebRequestModuleElement) -> Type



Set: Type(self: WebRequestModuleElement)=value

"""



class WebRequestModuleElementCollection(ConfigurationElementCollection,ICollection,IEnumerable):
 """
 Represents a container for Web request module configuration elements. This class cannot be inherited.

 

 WebRequestModuleElementCollection()
 """
 def Add(self,element):
  """
  Add(self: WebRequestModuleElementCollection,element: WebRequestModuleElement)

   Adds an element to the collection.

  

   element: The System.Net.Configuration.WebRequestModuleElement to add to the collection.
  """
  pass
 def BaseAdd(self,*args):
  """
  BaseAdd(self: ConfigurationElementCollection,index: int,element: ConfigurationElement)

   Adds a configuration element to the configuration element collection.

  

   index: The index location at which to add the specified System.Configuration.ConfigurationElement.

   element: The System.Configuration.ConfigurationElement to add.

  BaseAdd(self: ConfigurationElementCollection,element: ConfigurationElement,throwIfExists: bool)

   Adds a configuration element to the configuration element collection.

  

   element: The System.Configuration.ConfigurationElement to add.

   throwIfExists: true to throw an exception if the System.Configuration.ConfigurationElement specified is already 

    contained in the System.Configuration.ConfigurationElementCollection; otherwise,false.

  

  BaseAdd(self: ConfigurationElementCollection,element: ConfigurationElement)

   Adds a configuration element to the System.Configuration.ConfigurationElementCollection.

  

   element: The System.Configuration.ConfigurationElement to add.
  """
  pass
 def BaseClear(self,*args):
  """
  BaseClear(self: ConfigurationElementCollection)

   Removes all configuration element objects from the collection.
  """
  pass
 def BaseGet(self,*args):
  """
  BaseGet(self: ConfigurationElementCollection,index: int) -> ConfigurationElement

  

   Gets the configuration element at the specified index location.

  

   index: The index location of the System.Configuration.ConfigurationElement to return.

   Returns: The System.Configuration.ConfigurationElement at the specified index.

  BaseGet(self: ConfigurationElementCollection,key: object) -> ConfigurationElement

  

   Returns the configuration element with the specified key.

  

   key: The key of the element to return.

   Returns: The System.Configuration.ConfigurationElement with the specified key; otherwise,null.
  """
  pass
 def BaseGetAllKeys(self,*args):
  """
  BaseGetAllKeys(self: ConfigurationElementCollection) -> Array[object]

  

   Returns an array of the keys for all of the configuration elements contained in the 

    System.Configuration.ConfigurationElementCollection.

  

   Returns: An array that contains the keys for all of the System.Configuration.ConfigurationElement objects 

    contained in the System.Configuration.ConfigurationElementCollection.
  """
  pass
 def BaseGetKey(self,*args):
  """
  BaseGetKey(self: ConfigurationElementCollection,index: int) -> object

  

   Gets the key for the System.Configuration.ConfigurationElement at the specified index location.

  

   index: The index location for the System.Configuration.ConfigurationElement.

   Returns: The key for the specified System.Configuration.ConfigurationElement.
  """
  pass
 def BaseIndexOf(self,*args):
  """
  BaseIndexOf(self: ConfigurationElementCollection,element: ConfigurationElement) -> int

  

   The index of the specified System.Configuration.ConfigurationElement.

  

   element: The System.Configuration.ConfigurationElement for the specified index location.

   Returns: The index of the specified System.Configuration.ConfigurationElement; otherwise,-1.
  """
  pass
 def BaseIsRemoved(self,*args):
  """
  BaseIsRemoved(self: ConfigurationElementCollection,key: object) -> bool

  

   Gets a value indicating whether the System.Configuration.ConfigurationElement with the specified 

    key has been removed from the System.Configuration.ConfigurationElementCollection.

  

  

   key: The key of the element to check.

   Returns: true if the System.Configuration.ConfigurationElement with the specified key has been removed; 

    otherwise,false. The default is false.
  """
  pass
 def BaseRemove(self,*args):
  """
  BaseRemove(self: ConfigurationElementCollection,key: object)

   Removes a System.Configuration.ConfigurationElement from the collection.

  

   key: The key of the System.Configuration.ConfigurationElement to remove.
  """
  pass
 def BaseRemoveAt(self,*args):
  """
  BaseRemoveAt(self: ConfigurationElementCollection,index: int)

   Removes the System.Configuration.ConfigurationElement at the specified index location.

  

   index: The index location of the System.Configuration.ConfigurationElement to remove.
  """
  pass
 def Clear(self):
  """
  Clear(self: WebRequestModuleElementCollection)

   Removes all elements from the collection.
  """
  pass
 def CreateNewElement(self,*args):
  """
  CreateNewElement(self: WebRequestModuleElementCollection) -> ConfigurationElement

  CreateNewElement(self: ConfigurationElementCollection,elementName: str) -> ConfigurationElement

  

   Creates a new System.Configuration.ConfigurationElement when overridden in a derived class.

  

   elementName: The name of the System.Configuration.ConfigurationElement to create.

   Returns: A new System.Configuration.ConfigurationElement.
  """
  pass
 def DeserializeElement(self,*args):
  """
  DeserializeElement(self: ConfigurationElement,reader: XmlReader,serializeCollectionKey: bool)

   Reads XML from the configuration file.

  

   reader: The System.Xml.XmlReader that reads from the configuration file.

   serializeCollectionKey: true to serialize only the collection key properties; otherwise,false.
  """
  pass
 def GetElementKey(self,*args):
  """ GetElementKey(self: WebRequestModuleElementCollection,element: ConfigurationElement) -> object """
  pass
 def GetTransformedAssemblyString(self,*args):
  """
  GetTransformedAssemblyString(self: ConfigurationElement,assemblyName: str) -> str

  

   Returns the transformed version of the specified assembly name.

  

   assemblyName: The name of the assembly.

   Returns: The transformed version of the assembly name. If no transformer is available,the assemblyName 

    parameter value is returned unchanged. The 

    System.Configuration.Configuration.TypeStringTransformer property is null if no transformer is 

    available.
  """
  pass
 def GetTransformedTypeString(self,*args):
  """
  GetTransformedTypeString(self: ConfigurationElement,typeName: str) -> str

  

   Returns the transformed version of the specified type name.

  

   typeName: The name of the type.

   Returns: The transformed version of the specified type name. If no transformer is available,the typeName 

    parameter value is returned unchanged. The 

    System.Configuration.Configuration.TypeStringTransformer property is null if no transformer is 

    available.
  """
  pass
 def get_Item(self,*__args):
  """
  get_Item(self: ConfigurationElement,propertyName: str) -> object

  get_Item(self: ConfigurationElement,prop: ConfigurationProperty) -> object
  """
  pass
 def IndexOf(self,element):
  """
  IndexOf(self: WebRequestModuleElementCollection,element: WebRequestModuleElement) -> int

  

   Returns the index of the specified configuration element.

  

   element: A System.Net.Configuration.WebRequestModuleElement.

   Returns: The zero-based index of element.
  """
  pass
 def Init(self,*args):
  """
  Init(self: ConfigurationElement)

   Sets the System.Configuration.ConfigurationElement object to its initial state.
  """
  pass
 def InitializeDefault(self,*args):
  """
  InitializeDefault(self: ConfigurationElement)

   Used to initialize a default set of values for the System.Configuration.ConfigurationElement 

    object.
  """
  pass
 def IsElementName(self,*args):
  """
  IsElementName(self: ConfigurationElementCollection,elementName: str) -> bool

  

   Indicates whether the specified System.Configuration.ConfigurationElement exists in the 

    System.Configuration.ConfigurationElementCollection.

  

  

   elementName: The name of the element to verify.

   Returns: true if the element exists in the collection; otherwise,false. The default is false.
  """
  pass
 def IsElementRemovable(self,*args):
  """
  IsElementRemovable(self: ConfigurationElementCollection,element: ConfigurationElement) -> bool

  

   Gets a value indicating whether the specified System.Configuration.ConfigurationElement can be 

    removed from the System.Configuration.ConfigurationElementCollection.

  

  

   element: The element to check.

   Returns: true if the specified System.Configuration.ConfigurationElement can be removed from this 

    System.Configuration.ConfigurationElementCollection; otherwise,false. The default is true.
  """
  pass
 def IsModified(self,*args):
  """
  IsModified(self: ConfigurationElementCollection) -> bool

  

   Indicates whether this System.Configuration.ConfigurationElementCollection has been modified 

    since it was last saved or loaded when overridden in a derived class.

  

   Returns: true if any contained element has been modified; otherwise,false
  """
  pass
 def ListErrors(self,*args):
  """
  ListErrors(self: ConfigurationElement,errorList: IList)

   Adds the invalid-property errors in this System.Configuration.ConfigurationElement object,and 

    in all subelements,to the passed list.

  

  

   errorList: An object that implements the System.Collections.IList interface.
  """
  pass
 def OnDeserializeUnrecognizedAttribute(self,*args):
  """
  OnDeserializeUnrecognizedAttribute(self: ConfigurationElement,name: str,value: str) -> bool

  

   Gets a value indicating whether an unknown attribute is encountered during deserialization.

  

   name: The name of the unrecognized attribute.

   value: The value of the unrecognized attribute.

   Returns: true when an unknown attribute is encountered while deserializing; otherwise,false.
  """
  pass
 def OnDeserializeUnrecognizedElement(self,*args):
  """
  OnDeserializeUnrecognizedElement(self: ConfigurationElementCollection,elementName: str,reader: XmlReader) -> bool

  

   Causes the configuration system to throw an exception.

  

   elementName: The name of the unrecognized element.

   reader: An input stream that reads XML from the configuration file.

   Returns: true if the unrecognized element was deserialized successfully; otherwise,false. The default is 

    false.
  """
  pass
 def OnRequiredPropertyNotFound(self,*args):
  """
  OnRequiredPropertyNotFound(self: ConfigurationElement,name: str) -> object

  

   Throws an exception when a required property is not found.

  

   name: The name of the required attribute that was not found.

   Returns: None.
  """
  pass
 def PostDeserialize(self,*args):
  """
  PostDeserialize(self: ConfigurationElement)

   Called after deserialization.
  """
  pass
 def PreSerialize(self,*args):
  """
  PreSerialize(self: ConfigurationElement,writer: XmlWriter)

   Called before serialization.

  

   writer: The System.Xml.XmlWriter that will be used to serialize the 

    System.Configuration.ConfigurationElement.
  """
  pass
 def Remove(self,*__args):
  """
  Remove(self: WebRequestModuleElementCollection,name: str)

   Removes the element with the specified key.

  

   name: The key of the element to remove.

  Remove(self: WebRequestModuleElementCollection,element: WebRequestModuleElement)

   Removes the specified configuration element from the collection.

  

   element: The System.Net.Configuration.WebRequestModuleElement to remove.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: WebRequestModuleElementCollection,index: int)

   Removes the element at the specified index.

  

   index: The zero-based index of the element to remove.
  """
  pass
 def Reset(self,*args):
  """
  Reset(self: ConfigurationElementCollection,parentElement: ConfigurationElement)

   Resets the System.Configuration.ConfigurationElementCollection to its unmodified state when 

    overridden in a derived class.

  

  

   parentElement: The System.Configuration.ConfigurationElement representing the collection parent element,if 

    any; otherwise,null.
  """
  pass
 def ResetModified(self,*args):
  """
  ResetModified(self: ConfigurationElementCollection)

   Resets the value of the System.Configuration.ConfigurationElementCollection.IsModified property 

    to false when overridden in a derived class.
  """
  pass
 def SerializeElement(self,*args):
  """
  SerializeElement(self: ConfigurationElementCollection,writer: XmlWriter,serializeCollectionKey: bool) -> bool

  

   Writes the configuration data to an XML element in the configuration file when overridden in a 

    derived class.

  

  

   writer: Output stream that writes XML to the configuration file.

   serializeCollectionKey: true to serialize the collection key; otherwise,false.

   Returns: true if the System.Configuration.ConfigurationElementCollection was written to the configuration 

    file successfully.
  """
  pass
 def SerializeToXmlElement(self,*args):
  """
  SerializeToXmlElement(self: ConfigurationElement,writer: XmlWriter,elementName: str) -> bool

  

   Writes the outer tags of this configuration element to the configuration file when implemented 

    in a derived class.

  

  

   writer: The System.Xml.XmlWriter that writes to the configuration file.

   elementName: The name of the System.Configuration.ConfigurationElement to be written.

   Returns: true if writing was successful; otherwise,false.
  """
  pass
 def SetPropertyValue(self,*args):
  """
  SetPropertyValue(self: ConfigurationElement,prop: ConfigurationProperty,value: object,ignoreLocks: bool)

   Sets a property to the specified value.

  

   prop: The element property to set.

   value: The value to assign to the property.

   ignoreLocks: true if the locks on the property should be ignored; otherwise,false.
  """
  pass
 def SetReadOnly(self,*args):
  """
  SetReadOnly(self: ConfigurationElementCollection)

   Sets the System.Configuration.ConfigurationElementCollection.IsReadOnly property for the 

    System.Configuration.ConfigurationElementCollection object and for all sub-elements.
  """
  pass
 def set_Item(self,*__args):
  """ set_Item(self: ConfigurationElement,propertyName: str,value: object)set_Item(self: ConfigurationElement,prop: ConfigurationProperty,value: object) """
  pass
 def Unmerge(self,*args):
  """
  Unmerge(self: ConfigurationElementCollection,sourceElement: ConfigurationElement,parentElement: ConfigurationElement,saveMode: ConfigurationSaveMode)

   Reverses the effect of merging configuration information from different levels of the 

    configuration hierarchy

  

  

   sourceElement: A System.Configuration.ConfigurationElement object at the current level containing a merged view 

    of the properties.

  

   parentElement: The parent System.Configuration.ConfigurationElement object of the current element,or null if 

    this is the top level.

  

   saveMode: A System.Configuration.ConfigurationSaveMode enumerated value that determines which property 

    values to include.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]=x.__setitem__(i,y) <==> x[i]= """
  pass
 AddElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the System.Configuration.ConfigurationElement to associate with the add operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ClearElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name for the System.Configuration.ConfigurationElement to associate with the clear operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name used to identify this collection of elements in the configuration file when overridden in a derived class.



"""

 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of properties.



"""

 RemoveElementName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the System.Configuration.ConfigurationElement to associate with the remove operation in the System.Configuration.ConfigurationElementCollection when overridden in a derived class.



"""

 ThrowOnDuplicate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether an attempt to add a duplicate System.Configuration.ConfigurationElement to the System.Configuration.ConfigurationElementCollection will cause an exception to be thrown.



"""



class WebRequestModulesSection(ConfigurationSection):
 """
 Represents the configuration section for Web request modules. This class cannot be inherited.

 

 WebRequestModulesSection()
 """
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 WebRequestModules=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of Web request modules in the section.



Get: WebRequestModules(self: WebRequestModulesSection) -> WebRequestModuleElementCollection



"""



class WebUtilityElement(ConfigurationElement):
 """ WebUtilityElement() """
 ElementProperty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ConfigurationElementProperty object that represents the System.Configuration.ConfigurationElement object itself.



"""

 EvaluationContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Configuration.ContextInformation object for the System.Configuration.ConfigurationElement object.



"""

 HasContext=property(lambda self: object(),lambda self,v: None,lambda self: None)

 Properties=property(lambda self: object(),lambda self,v: None,lambda self: None)

 UnicodeDecodingConformance=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: UnicodeDecodingConformance(self: WebUtilityElement) -> UnicodeDecodingConformance



Set: UnicodeDecodingConformance(self: WebUtilityElement)=value

"""

 UnicodeEncodingConformance=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: UnicodeEncodingConformance(self: WebUtilityElement) -> UnicodeEncodingConformance



Set: UnicodeEncodingConformance(self: WebUtilityElement)=value

"""






class TypeLibTypeFlags(Enum,IComparable,IFormattable,IConvertible):
 """
 Describes the original settings of the System.Runtime.InteropServices.TYPEFLAGS in the COM type library from which the type was imported.

 

 enum (flags) TypeLibTypeFlags,values: FAggregatable (1024),FAppObject (1),FCanCreate (2),FControl (32),FDispatchable (4096),FDual (64),FHidden (16),FLicensed (4),FNonExtensible (128),FOleAutomation (256),FPreDeclId (8),FReplaceable (2048),FRestricted (512),FReverseBind (8192)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 FAggregatable=None
 FAppObject=None
 FCanCreate=None
 FControl=None
 FDispatchable=None
 FDual=None
 FHidden=None
 FLicensed=None
 FNonExtensible=None
 FOleAutomation=None
 FPreDeclId=None
 FReplaceable=None
 FRestricted=None
 FReverseBind=None
 value__=None

